@@ -4,7 +4,7 @@ use crate::item::ItemTitleResolver;
 use crate::money::{Currency, Money};
 use address::Address;
 use async_trait::async_trait;
-use chrono::{DateTime, Utc};
+pub use chrono::{DateTime, Utc};
 use inventory::StockIssue;
 use invoice::{Invoice, InvoiceCalculator};
 use item::Item;
